@@ -38,6 +38,10 @@ summary.mvgam = function(object,
                          smooth_test = TRUE,
                          digits = 2, ...){
 
+#### Some adjustments for cleaner summaries ####
+  if(attr(object$model_data, 'trend_model') == 'None' &
+     object$use_lv & object$family != 'nmix') attr(object$model_data, 'trend_model') <- 'RW'
+
 #### Smooth tests ####
   if(smooth_test){
     if(inherits(object$trend_model, 'mvgam_trend')){
@@ -282,7 +286,12 @@ if(!is.null(attr(object$mgcv_model, 'gp_att_table'))){
 }
 
 if(any(!is.na(object$sp_names)) & smooth_test){
-  gam_sig_table <- summary(object$mgcv_model)$s.table[, c(1,2,3,4), drop = FALSE]
+  gam_sig_table <- try(suppressWarnings(summary(object$mgcv_model)$s.table[, c(1,2,3,4), drop = FALSE]), silent = TRUE)
+  if(inherits(gam_sig_table, 'try-error')){
+    object$mgcv_model$R <- NULL
+    gam_sig_table <- suppressWarnings(summary(object$mgcv_model)$s.table[, c(1,2,3,4), drop = FALSE])
+    gam_sig_table[,2] <- unlist(purrr::map(object$mgcv_model$smooth, 'df'), use.names = FALSE)
+  }
   if(!is.null(attr(object$mgcv_model, 'gp_att_table'))){
     gp_names <- unlist(purrr::map(attr(object$mgcv_model,
                                        'gp_att_table'), 'name'))
@@ -328,7 +337,10 @@ if(object$use_lv){
         }
         print(suppressWarnings(mcmc_summary(object$model_output, c('drift', 'theta'),
                            digits = digits,
-                           variational = object$algorithm %in% c('fullrank', 'meanfield', 'laplace', 'pathfinder')))[,c(3:7)])
+                           variational = object$algorithm %in% c('fullrank',
+                                                                 'meanfield',
+                                                                 'laplace',
+                                                                 'pathfinder')))[,c(3:7)])
       } else {
         if(!is.null(object$trend_call)){
           if(inherits(object$trend_model, 'mvgam_trend')){
@@ -336,7 +348,7 @@ if(object$use_lv){
           } else {
             trend_model <- object$trend_model
           }
-          if(trend_model == 'None'){
+          if(trend_model == 'None' & object$family == 'nmix'){
 
           } else {
             cat("\nProcess error parameter estimates:\n")
@@ -706,7 +718,13 @@ if(!is.null(object$trend_call)){
   }
 
   if(any(!is.na(object$trend_sp_names)) & smooth_test){
-    gam_sig_table <- summary(object$trend_mgcv_model)$s.table[, c(1,2,3,4), drop = FALSE]
+
+    gam_sig_table <- try(suppressWarnings(summary(object$trend_mgcv_model)$s.table[, c(1,2,3,4), drop = FALSE]), silent = TRUE)
+    if(inherits(gam_sig_table, 'try-error')){
+      object$trend_mgcv_model$R <- NULL
+      gam_sig_table <- suppressWarnings(summary(object$trend_mgcv_model)$s.table[, c(1,2,3,4), drop = FALSE])
+      gam_sig_table[,2] <- unlist(purrr::map(object$trend_mgcv_model$smooth, 'df'), use.names = FALSE)
+    }
     if(!is.null(attr(object$trend_mgcv_model, 'gp_att_table'))){
       gp_names <- unlist(purrr::map(attr(object$trend_mgcv_model, 'gp_att_table'), 'name'))
       if(all(rownames(gam_sig_table) %in% gsub('gp(', 's(', gp_names, fixed = TRUE))){
